@@ -1,10 +1,14 @@
 import numpy as np
 import pandas as pd
 from libpysal import weights
+from packaging.version import Version
 from scipy import stats
+from sklearn import __version__ as sklearn_version
 from sklearn.base import BaseEstimator
 from sklearn.utils import check_array
 
+SKL_GE_16 = Version(sklearn_version) >= Version("1.6")
+
 
 class Geary_Local_MV(BaseEstimator):  # noqa: N801
     """Local Geary - Multivariate"""
@@ -75,12 +79,15 @@ class Geary_Local_MV(BaseEstimator):  # noqa: N801
         >>> lG_mv.localG[0:5]
         >>> lG_mv.p_sim[0:5]
         """
+
+        all_finite_kwarg = "ensure_all_finite" if SKL_GE_16 else "force_all_finite"
+
         self.variables = check_array(
             variables,
             accept_sparse=False,
             dtype="float",
-            force_all_finite=True,
             estimator=self,
+            **{all_finite_kwarg: True},
         )
 
         w = self.connectivity
