@@ -277,12 +277,12 @@ def areal_entropy(polygons=None, areas=None, local=False, base=numpy.e):
     >>> r2 = geopandas.read_file('tests/regions.zip', layer='regions2')
     >>> areal_entropy(polygons=r1)
     """
-    assert not (
-        (polygons is None) & (areas is None)
-    ), "Either polygons or precomputed areas must be provided."
-    assert not (
-        (polygons is not None) & (areas is not None)
-    ), "Only one of polygons or areas should be provided."
+    assert not ((polygons is None) & (areas is None)), (
+        "Either polygons or precomputed areas must be provided."
+    )
+    assert not ((polygons is not None) & (areas is not None)), (
+        "Only one of polygons or areas should be provided."
+    )
     if polygons is None:
         assert areas is not None, "If polygons are not provided, areas should be."
     if areas is None:
